@@ -10,19 +10,24 @@ import pkg_resources
 import sys
 import platform
 from . import constant as constant
+from lastversion import lastversion
+import coloredlogs
 
 
-def init_log(log_file, create_file=True, stream_log_level=logging.WARN, file_log_level=logging.INFO):
+def init_log(log_file, create_file=True, stream_log_level=logging.INFO, file_log_level=logging.DEBUG):
 
     logger = logging.getLogger(constant.LOGGER_NAME)
-    
+
     if not logger.hasHandlers():
         logger.setLevel(logging.DEBUG)
         log_dir = os.path.dirname(log_file)
         Path(log_dir).mkdir(parents=True, exist_ok=True)
 
-        if create_file:
+        coloredlogs.DEFAULT_LOG_FORMAT = '%(message)s'
+        coloredlogs.DEFAULT_LOG_LEVEL = stream_log_level
+        coloredlogs.install(logger=logger)
 
+        if create_file:
             file_handlder = logging.FileHandler(log_file)
             file_handlder.setLevel(file_log_level)
             file_formatter = logging.Formatter('[%(levelname)7s] %(message)s')
@@ -30,19 +35,27 @@ def init_log(log_file, create_file=True, stream_log_level=logging.WARN, file_log
             file_handlder.propagate = False
             logger.addHandler(file_handlder)
 
-        console_handler = logging.StreamHandler()
-        console_handler.setLevel(stream_log_level)
-        console_formatter = logging.Formatter('%(message)s')
-        console_handler.setFormatter(console_formatter)
-        console_handler.propagate = False
-        logger.addHandler(console_handler)
-
         logger.propagate = False
 
     return logger
 
 
-def init_log_item(main_package_name="", path_to_analyze= ""):
+def init_check_latest_version(pkg_version="", main_package_name=""):
+
+    logger = logging.getLogger(constant.LOGGER_NAME)
+
+    try:
+        has_update = lastversion.has_update(repo=main_package_name, at='pip', current_version=pkg_version)
+        if has_update:
+            logger.info('### Version Info ###')
+            logger.warning('Newer version is available : v.{}'.format(str(has_update)))
+            logger.warning('You can update it with command (\'pip install ' + main_package_name + ' --upgrade\')')
+    except TypeError:
+        logger.warning('Cannot check the lastest version on PIP')
+        logger.warning('You could use already installed version\n')
+
+
+def init_log_item(main_package_name="", path_to_analyze=""):
 
     _PYTHON_VERSION = sys.version_info[0]
     _result_log = {
@@ -52,8 +65,9 @@ def init_log_item(main_package_name="", path_to_analyze= ""):
     }
     if main_package_name != "":
         pkg_version = pkg_resources.get_distribution(main_package_name).version
-        _result_log["Tool Info"] = main_package_name +" v."+pkg_version
+        init_check_latest_version(pkg_version, main_package_name)
+        _result_log["Tool Info"] = main_package_name + " v." + pkg_version
     if path_to_analyze != "":
-       _result_log["Path to analyze"] = path_to_analyze
+        _result_log["Path to analyze"] = path_to_analyze
 
     return _result_log
